# -*- coding: utf-8 -*-

try:
    import pandas  # noqa
    _has_pandas = True
except ImportError:
    _has_pandas = False
